#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global base_name jaxen
%global flavor %{nil}
%if "%{flavor}" == "bootstrap"
%bcond_without bootstrap
%else
%bcond_with bootstrap
%endif
Version:        2.0.0
Release:        1.4
Summary:        An XPath engine written in Java
License:        BSD-3-Clause
URL:            https://github.com/jaxen-xpath/jaxen
Source0:        %{url}/archive/v%{version}/%{base_name}-%{version}.tar.gz
Source1:        %{base_name}-build.xml
BuildRequires:  ant
BuildRequires:  javapackages-local >= 6
BuildRequires:  jdom
BuildArch:      noarch
%if %{with bootstrap}
Name:           %{base_name}-bootstrap
%else
Name:           %{base_name}
%endif
%if %{without bootstrap}
BuildRequires:  %{base_name}-bootstrap
BuildRequires:  dom4j-bootstrap
BuildRequires:  fdupes
BuildRequires:  xom
#!BuildIgnore:  %{base_name}
#!BuildIgnore:  mvn(jaxen:jaxen)
Conflicts:      %{base_name}-bootstrap
Obsoletes:      %{base_name}-bootstrap
%else
Conflicts:      %{base_name}
%endif

%description
Jaxen is an open source XPath library written in Java. It is adaptable
to many different object models, including DOM, XOM, dom4j, and JDOM.
Is it also possible to write adapters that treat non-XML trees such as compiled
Java byte code or Java beans as XML, thus enabling you to query these trees
with XPath too.

%if %{without bootstrap}
%package        demo
Summary:        Samples for %{name}
Requires:       %{name} = %{version}-%{release}

%description    demo
%{summary}.

%package        javadoc
Summary:        Javadoc for %{name}

%description    javadoc
%{summary}.
%endif

%prep
%setup -q -n %{base_name}-%{version}
cp %{SOURCE1} core/build.xml

%if %{with bootstrap}
rm -rf core/src/java/main/org/jaxen/dom4j
%pom_remove_dep -r dom4j:dom4j

rm -rf core/src/java/main/org/jaxen/xom
%pom_remove_dep -r xom:xom
%endif

%build
mkdir -p core/lib
build-jar-repository -s core/lib jdom
%if %{without bootstrap}
build-jar-repository -s core/lib dom4j xom
%endif
pushd core
%{ant} jar
%if %{without bootstrap}
%{ant} javadoc
%endif
popd

%install
# jar
install -dm 0755 %{buildroot}%{_javadir}
install -pm 0644 core/target/%{base_name}-%{version}.jar %{buildroot}%{_javadir}/%{base_name}.jar

%if %{without bootstrap}
# pom
install -dm 0755 %{buildroot}%{_mavenpomdir}
%{mvn_install_pom} core/pom.xml %{buildroot}%{_mavenpomdir}/%{base_name}.pom
%add_maven_depmap %{base_name}.pom %{base_name}.jar

# demo
install -d -m 755 %{buildroot}%{_datadir}/%{base_name}/samples
cp -pr core/src/java/samples/* %{buildroot}%{_datadir}/%{base_name}/samples
%fdupes -s %{buildroot}%{_datadir}/%{base_name}

# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}/%{base_name}
cp -r core/target/site/apidocs %{buildroot}%{_javadocdir}/%{base_name}
%fdupes -s %{buildroot}%{_javadocdir}/%{base_name}

%files -f .mfiles
%license LICENSE.txt

%files javadoc
%license LICENSE.txt
%{_javadocdir}/%{base_name}

%files demo
%{_datadir}/%{base_name}

%else

%files
%{_javadir}/%{base_name}.jar

%endif

%changelog
* Fri Sep 22 2023 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 2.0.0
  * Changes:
    + Despite the major version bump, this should be a drop in
    replacement for almost every project, The two major possible
    incompatibilities are:
    ° The minimum supported Java version is now 1.5, up from 1.4
    in 1.2.0 and 1.3 in 1.1.6.
    ° dom4j, XOM, and JDOM are now optional dependencies so if a
    project was depending on them to be loaded transitively it
    will need to add explicit dependencies to build.
    + On the plus side, this makes classpaths much smaller and less
    complex, and will shut up a lot of noise from static analysis
    tools.
    + In addition the Jaxen core code is also a little smaller and
    has fixed a few minor bugs in XPath evaluation, mostly weird
    cases found by fuzzing that are unlikely to arise in practice.
* Thu Aug 24 2023 Fridrich Strba <fstrba@suse.com>
- Move to a jaxen multibuild package where the *-bootstrap version
  is one of the flavours
- Update to 1.2.0
  * org.w3c.dom UserDataHandler interface is no longer bundled
    since it's available in Java 1.5 and later
  * org.jaxen.pattern package has been deprecated and is scheduled
    for removal in 2.0
* Sat Mar 19 2022 Fridrich Strba <fstrba@suse.com>
- Build with source/target levels 8
- Clean-up the build system
- Removed patch:
  * jaxen-bootstrap-project_xml.patch
    + not needed in the rewamped build system
* Fri Sep  8 2017 fstrba@suse.com
- Build with java target and source level 1.6 in order to allow
  building with jdk9
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Wed May 20 2009 mvyskocil@suse.cz
- Used dom4j-1.6.1-debian.tar.bz2 for build
  It does not contains a license problematic parts
* Tue May 12 2009 mvyskocil@suse.cz
- Initial packaging of jaxen-bootstrap in SUSE (from jpp 5.0)
